/*  $Id: ConfigHandler.java 1035 2010-06-15 13:08:33Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2010 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.util;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.Properties;
/**
 *
 * @version $Id: ConfigHandler.java 1035 2010-06-15 13:08:33Z sdevaux $
 * @author Sebastien Devaux
 */
public class ConfigHandler {
	/**
	 * Default constructor
	 */
	public ConfigHandler() {
	}
	/**
	 * @param 
	 */
	public ConfigHandler(
				Properties def,
				String file,
				String[] args,
				ConfigChecker ch) {
		setDefault(def);
		setFilePath(file);
		setArgs(args);
		setChecker(ch);
	}				
	/**
	 * Load rc file and scan command line arguments.
	 * @return error code, one of CC_ constants of 
	 *	net.eduvax.util.ConfigChecker interface. 
	 * @see net.eduvax.util.ConfigChecker
	 */
	public int load() {
		if (_defaultConfig==null) {
			_config=new Properties(System.getProperties());
		}
		else {
			_config=new Properties(_defaultConfig);
		}	
		if (filePath!=null) {
			try {
				_config.load(new FileInputStream(filePath));
			}
			catch (IOException ex) {
				// Logger.configure(prop);
				SLogger log=Logger.getSLogger("net.eduvax.util");
				
				log.warn("Can't load rcfile : "+ex);
			}
		}
		if (_cmdArgs!=null) {
			for (int i=0;i<_cmdArgs.length;i++) {
				if (_cmdArgs[i].startsWith("-") && (i-1)<_cmdArgs.length ) {
					_config.setProperty(_cmdArgs[i].substring(1),_cmdArgs[i+1]);
					i++;
				}
			}
		}
		if (_checker!=null) {
			return _checker.check(_config);
		}	
		else {
			return ConfigChecker.CC_OK;
		}
	}
	/**
	 * get configuration.
	 * This method should not be called before load(). Configuration will not 
	 * be build before load() call.
	 * @see #load()
	 * @return loaded and checked configuration.
	 */
    public Properties get() {
        return _config; 
    }        
	/**
	 * set default configuration.
	 * @param def default properties
	 */
	public void setDefault(Properties def) {
		_defaultConfig=def;
	}
	/**
	 * set checker to use to verify configuration.
	 * @param ch checker.
	 */
	public void setChecker(ConfigChecker ch) {
		_checker=ch;
	}	
	/**
	 * set command line arguments to parse
	 * @param args
	 */
	public void setArgs(String[] args) {
		_cmdArgs=args;
	}
	/**
	 * set rc file path.
	 * if path starts with "~", path is relative to user home directory.
	 * @param path rc file path
	 */
	public void setFilePath(String path) {
		if (path!=null) {
			if (path.startsWith("~")) {
				filePath=System.getProperty("user.home")+path.substring(1);
			}
			else {
				filePath=path;
			}
		}	
	}
	//----------------------------------------------------
	// Private properties.
	/** default configuration. */
	private Properties _defaultConfig=null;
	/** configuration. */
	Properties _config=null;
	/** configuration checker. */
	private ConfigChecker _checker=null;
	/** command line arguments. */
	private String[] _cmdArgs=null;
	/** rc file path. */
	private String filePath=null;
}
