/*  $Id: TestArchive.java 1335 2012-08-25 13:27:49Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package test;

import java.io.File;
import org.junit.*;
import static org.junit.Assert.*;


import net.eduvax.util.App;
import net.eduvax.util.Archive;
import net.eduvax.util.ErrorHandler;
import net.eduvax.util.Error;


public class TestArchive implements ErrorHandler {
    @Before public void setUp() 
    {
        App.init();
    }

    @Test public void testZip()
    {
        File zipf=new File("bin/test.zip");
        File zipbak=new File("bin/test.zip.bak");
        if (zipf.exists())
        {
            zipf.delete();
        }
        if (zipbak.exists())
        {
            zipbak.delete();
        }
        Archive zip=new Archive("bin/test.zip","src/",Archive.OM_IGNORE);
        zip.setErrHandler(App.get().getErrHandler(this));
        zip.addFile("src/test/mime.types");
        zip.addFile("src/package.xml");
        zip.run();
        assertTrue("No zip creation error.",checkAndReset());
        assertTrue("zip file created",zipf.exists());
        zip=new Archive("bin/test.zip","src/",Archive.OM_STOP);
        zip.setErrHandler(App.get().getErrHandler(this));
        zip.addFile("src/test/mime.types");
        zip.run();
        assertFalse("Don't overwrite",checkAndReset());
        zip=new Archive("bin/test.zip","src/",Archive.OM_BACKUP);
        zip.setErrHandler(App.get().getErrHandler(this));
        zip.addFile("src/test/mime.types");
        zip.run();
        assertTrue("No error",checkAndReset());
        assertTrue("zip file backuped",zipbak.exists());
        assertTrue("New zip file",zipf.exists());
        
    }
    // ### mise en oeuvre ErrorHandler ###
    private int _errCount=0;
    public void handle(Error err) {
        _errCount++;
    }
    public boolean checkOnly() {
        return _errCount==0;
    }
    public boolean checkAndReset() {
        boolean res=_errCount==0;
        _errCount=0;
        return res;
    }
}
